<?php
	
	// php PHP/schedule.php team=sf completedGames=2 futureGames=2 media=TV timezoneOffset=-3

	error_reporting(E_ERROR);

	$abbreviationToTeamNameArray = array(
		'bal' => 'Orioles',
		'bos' => 'Red Sox',
		'nyy' => 'Yankees',
		'tb'  => 'Rays',
		'tor' => 'Blue Jays',
		
		'cws' => 'White Sox',
		'cle' => 'Indians',
		'det' => 'Tigers',
		'kc'  => 'Royals',
		'min' => 'Twins',
		
		'ana' => 'Angels',
		'oak' => 'Athletics',
		'sea' => 'Mariners',
		'tex' => 'Rangers',
		
		'atl' => 'Braves',
		'mia' => 'Marlins',
		'nym' => 'Mets',
		'phi' => 'Phillies',
		'was' => 'Nationals',
		
		'chc' => 'Cubs',
		'cin' => 'Reds',
		'hou' => 'Astros',
		'mil' => 'Brewers',
		'pit' => 'Pirates',
		'stl' => 'Cardinals',
		
		'ari' => 'Diamondbacks',
		'col' => 'Rockies',
		'la'  => 'Dodgers',
		'sd'  => 'Padres',
		'sf'  => 'Giants'
	);

	// get command line arguments
	foreach($_SERVER["argv"] as $argument) {
	
		if( !strpos($argument, "=") ) {
			continue;
		}
		
		$key = substr($argument, 0, strpos($argument, "="));
		$value = substr($argument, strpos($argument, "=")+1, strlen($argument));
		
		$args[$key] = $value;
	}
	
	// set default date offset
	if( !isset($args['dateOffset']) ) {
		$args['dateOffset'] = 0;
	}
	
	// set today's date
	$args['today'] = strtotime( $args['dateOffset'] . " day" );
	$args['todayFormatted'] = date('Y-m-d', $args['today']);
	
	// set timezone based on preferences
	switch( $args['timezoneOffset'] ) {
	
		case -3:	date_default_timezone_set('America/Los_Angeles');	break;
		case -2:	date_default_timezone_set('America/Denver');		break;
		case -1:	date_default_timezone_set('America/Chicago');		break;
		
		case -4:	date_default_timezone_set('America/Anchorage');		break;
		case -6:	date_default_timezone_set('Pacific/Honolulu');		break;
		
		default:	date_default_timezone_set('America/New_York');		break;
	}
	
	// Create the Data Array
	// ================================================================================
	
	$dataArray = array();
	
	// get start and end dates
	$secondsPerDay = 24 * 60 * 60;
	
	$startTime = $args['today'] - ((int)$args['completedGames'] * $secondsPerDay);
	$startTime = strtotime( date('Y-m-d', $startTime) );
	
	$endTime = $args['today'] + (((int)$args['futureGames'] + 1) * $secondsPerDay);
	$endTime = strtotime( date('Y-m-d', $endTime) );
	
	// get content from the individual scoreboard files
	for( $time = $startTime; $time < $endTime; $time += $secondsPerDay ) {
			
		// create the key
		$gameKey = date('Y-m-d', $time);
		
		// create the empty array
		$dataArray[$gameKey] = array();
			
		// set the date
		$dataArray[$gameKey]['shortdate'] = date('D. j', $time);
		$dataArray[$gameKey]['longdate'] = date('D. M j, Y', $time);
		
		// get data
		$url = 'http://gd2.mlb.com/components/game/mlb/year_' . date('Y', $time) . '/month_' . date('m', $time) . '/day_' . date('d', $time) . '/master_scoreboard.xml';
		
		// download source
		$dom = new domdocument;
		@ $dom->loadHTMLFile($url);
		$xpath = new domxpath($dom);
		
		// get fixed team code
		$teamCode = strtoupper($args['team']);
		
		if( $teamCode == 'ANA' ) {
			$teamCode = 'LAA';
		}
		
		else if( $teamCode == 'LA' ) {
			$teamCode = 'LAD';
		}
		
		else if( $teamCode == 'WAS' ) {
			$teamCode = 'WSH';
		}
		
		// get all game nodes for this team
		$allNodes = $xpath->query('//game[@away_name_abbrev="' . $teamCode . '" or @home_name_abbrev="' . $teamCode . '"]');
		
		// loop through each game
		foreach ($allNodes as $node) {
			
			// figure out if team is away
			$teamIsAway = ($teamCode == $node->getAttribute('away_name_abbrev'));
			
			// opponent
			if( $teamIsAway ) {
				$opponent = 'at ' . $node->getAttribute('home_team_name');
			}
			
			else {
				$opponent = 'vs ' . $node->getAttribute('away_team_name');
			}
			
			// opponent is already set, so append it
			if( isset($dataArray[$gameKey]['opponent']) &&
				$opponent != $dataArray[$gameKey]['opponent'] ) {
				
				$dataArray[$gameKey]['opponent'] .= " / " . $opponent;
			}
			
			else {
				$dataArray[$gameKey]['opponent'] = $opponent;
			}
			
			// create array for this game
			$gameArray = array();
			
			// game time
			$currentTimeZone = date('T');
			$currentTimeZone = 'E' . substr($currentTimeZone, strlen($currentTimeZone)-2);
			
			$timeStamp = strtotime(date('Y-m-d', $time) . ' ' . $node->getAttribute('time') . ' ' . $node->getAttribute('ampm') . ' ' . $currentTimeZone);
			
			$gameArray['startTime'] = date('g:i', $timeStamp);
			
			// status
			$status = getAttributeOfFirstChildElementByTagName($node, "status", 'status');
			
			switch($status) {
				
				// pre-event
				case 'Preview':
				case 'Pre-Game':
				case 'Warmup':
				case 'PRE_GAME':
				case 'IMMEDIATE_PREGAME':
				case 'P':
					$status = 'pre-event';		break;
				
				// mid-event
				case 'In Progress':
					$status = 'mid-event';		break;
				
				// post-event
				case 'Final':
				case 'Completed Early':
				case 'Game Over':
				case 'GAME_OVER':
				case 'FINAL':
				case 'F':
				case 'GO':
					$status = 'post-event';		break;
					
				// postponed
				case 'PO':
				case 'Postponed':
					$status = 'postponed';		break;
					
				// delayed
				case 'Delayed':
				case 'Delayed Start':
					$status = 'delayed';		break;
					
				// suspended
				case 'Suspended':
					$status = 'suspended';		break;
			}
			
			$gameArray['status'] = $status;
			
			// score
			$awayScore = getAttributeOfFirstChildElementByTagName($node, "linescore/r", 'away');
			$homeScore = getAttributeOfFirstChildElementByTagName($node, "linescore/r", 'home');
				
			if( $teamIsAway ) {
				$ourScore = $awayScore;
				$theirScore = $homeScore;
				
			} else {
				$ourScore = $homeScore;
				$theirScore = $awayScore;
			}
			
			$score = '';
			
			if( $ourScore != '' && $theirScore != '' ) {
				$score = $ourScore . '-' . $theirScore;
			}
			
			$gameArray['score'] = $score;
			
			// win/loss
			$winOrLoss = '';
			
			if( $ourScore != '' && $theirScore != '' ) {
			
				if( intval($ourScore) > intval($theirScore) ) {
					$winOrLoss = 'W';
				}
				
				else if( intval($ourScore) < intval($theirScore) ) {
					$winOrLoss = 'L';
				}
				
				else if( intval($ourScore) == intval($theirScore) ) {
					$winOrLoss = 'T';
				}
			}
			
			$gameArray['winOrLoss'] = $winOrLoss;
			
			// win/loss and score
			$gameArray['winOrLossAndScore'] = $gameArray["winOrLoss"] . ' ' . $gameArray["score"];
			
			// media
			$broadcast = getFirstChildElementByTagName($node, "broadcast");
            $broadcastTeam = getFirstChildElementByTagName($broadcast, $teamIsAway ? "away" : "home");
			
			// tv
			$tvElement = getFirstChildElementByTagName($broadcastTeam, "tv");
			$gameArray['tv'] = $tvElement->nodeValue;
			
			// radio
			$radioElement = getFirstChildElementByTagName($broadcastTeam, "radio");
			$gameArray['radio'] = $radioElement->nodeValue;
			
			// inning
			$gameArray['inning'] = getAttributeOfFirstChildElementByTagName($node, "status", 'inning');
			
			// inning half
			$inningHalf = '';
			$inningHalfImage = '';
			
			$isTopOfInning = getAttributeOfFirstChildElementByTagName($node, "status", 'top_inning');
			
			if( "" != $isTopOfInning ) {
				
				// top
				if( 'Y' == $isTopOfInning ) {
					$inningHalf = 'Top';
					$inningHalfImage = '<div class="arrow"><img src="Images/uparrow.png" alt="Top of inning" /></div>';
				}
				
				// bottom
				else {
					$inningHalf = 'Bot';
					$inningHalfImage = '<div class="arrow"><img src="Images/downarrow.png" alt="Bottom of inning" /></div>';
				}
			}
			
			$gameArray['inningHalf'] = $inningHalf;
			$gameArray['inningHalfImage'] = $inningHalfImage;
			
			// inning and score
			$gameArray['inningHalfInningImageAndScore'] = $gameArray['inning'] . $gameArray['inningHalfImage'] . ' ' . $gameArray['score'];
			$gameArray['inningHalfInningAndScore'] = $gameArray['inningHalf'] . ' ' . $gameArray['inning'] . ', ' . $gameArray['score'];
			
			// men on base
			$menOnBase = getAttributeOfFirstChildElementByTagName($node, "runners_on_base", 'status');
			
			switch( $menOnBase ) {
			
				case '0':	$menOnBase = '';	break;
				case '1':	$menOnBase = 'man on first';	break;
				case '2':	$menOnBase = 'man on second';	break;
				case '3':	$menOnBase = 'man on third';	break;
				case '4':	$menOnBase = 'men on first and second';	break;
				case '5':	$menOnBase = 'men on first and third';	break;
				case '6':	$menOnBase = 'men on second and third';	break;
				case '7':	$menOnBase = 'bases loaded';	break;
			}
			
			$gameArray['menOnBase'] = $menOnBase;
			
			// outs
			$outs = getAttributeOfFirstChildElementByTagName($node, "status", 'o');
			
			if( "" != $outs ) {
				
				if( $outs == '1' ) {
					$outs .= ' out';
				}
				
				else {
					$outs .= ' outs';
				}
			}
			
			$gameArray['outs'] = $outs;
			
			// away starter
			$awayStarter = getAttributeOfFirstChildElementByTagName($node, "away_probable_pitcher", 'last_name');
			
			$awayStarterWins = getAttributeOfFirstChildElementByTagName($node, "away_probable_pitcher", 'wins');
			$awayStarterLosses = getAttributeOfFirstChildElementByTagName($node, "away_probable_pitcher", 'losses');
			
			if( '' != $awayStarterWins &&
				'' != $awayStarterLosses ) {
				
				$awayStarter .= ' (' . $awayStarterWins . '-' . $awayStarterLosses . ')';
			}
			
			// home starter
			$homeStarter = getAttributeOfFirstChildElementByTagName($node, "home_probable_pitcher", 'last_name');
			
			$homeStarterWins = getAttributeOfFirstChildElementByTagName($node, "home_probable_pitcher", 'wins');
			$homeStarterLosses = getAttributeOfFirstChildElementByTagName($node, "home_probable_pitcher", 'losses');
			
			if( '' != $homeStarterWins &&
				'' != $homeStarterLosses ) {
				
				$homeStarter .= ' (' . $homeStarterWins . '-' . $homeStarterLosses . ')';
			}
			
			// add both starers
			if( $teamIsAway ) {
				$gameArray['teamStarter'] = $awayStarter;
				$gameArray['opponentStarter'] = $homeStarter;
				
			}
			
			else {
				$gameArray['teamStarter'] = $homeStarter;
				$gameArray['opponentStarter'] = $awayStarter;
			}
			
			// winning pitchers
			$winningPitcher = '';
			
			$winningPitcherName = getAttributeOfFirstChildElementByTagName($node, "winning_pitcher", 'last');
			$winningPitcherWins = getAttributeOfFirstChildElementByTagName($node, "winning_pitcher", 'wins');
			$winningPitcherLosses = getAttributeOfFirstChildElementByTagName($node, "winning_pitcher", 'losses');
			
			if( $winningPitcherName && "" != $winningPitcherName ) {
				
				$winningPitcher = 'W: ' . $winningPitcherName;
				
				if( '' != $winningPitcherWins && '' != $winningPitcherLosses ) {
					$winningPitcher .= ' (' . $winningPitcherWins . '-' . $winningPitcherLosses . ')';
				}
			}
			
			$gameArray['winningPitcher'] = $winningPitcher;
			
			// losing pitcher
			$losingPitcher = '';
			
			$losingPitcherName = getAttributeOfFirstChildElementByTagName($node, "losing_pitcher", 'last');
			$losingPitcherWins = getAttributeOfFirstChildElementByTagName($node, "losing_pitcher", 'wins');
			$losingPitcherLosses = getAttributeOfFirstChildElementByTagName($node, "losing_pitcher", 'losses');
			
			if( $losingPitcherName && "" != $losingPitcherName ) {
			
				$losingPitcher = 'L: ' . $losingPitcherName;
				
				if( '' != $losingPitcherWins && '' != $losingPitcherLosses ) {
					$losingPitcher .= ' (' . $losingPitcherWins . '-' . $losingPitcherLosses . ')';
				}
			}
			
			$gameArray['losingPitcher'] = $losingPitcher;
			
			// links
			$gameID = '';
			
			// preview
			if( 'pre-event' == $status ) {
			
				if( $teamIsAway ) {
					$link = getAttributeOfFirstChildElementByTagName($node, 'links', 'away_preview');
				}
				
				else {
					$link = getAttributeOfFirstChildElementByTagName($node, 'links', 'home_preview');
				}
			}
			
			// wrapup
			else {
				$link = getAttributeOfFirstChildElementByTagName($node, 'links', 'wrapup');
			}
			
			// game day
			if( '' == $link ) {
				
				$gameID = $node->getAttribute('id');
				$gameID = str_ireplace('/', '_', $gameID);
				$gameID = str_ireplace('-', '_', $gameID);
				
				$link = '/mlb/gameday/index.jsp?gid=' . $gameID;
			}
			
			$gameArray['link'] = 'http://mlb.mlb.com' . $link;
			
			// add to overall array
			$dataArray[$gameKey]["games"][] = $gameArray;
		}
	}
	
	// Print Output
	// ================================================================================
	
	// open the div
	echo '<div id="gameData">' . "\n";
	
	// print out all games
	$count = -1;
	$gameHTML = '';
	foreach( $dataArray as $date => $dateArray ) {
        
        // up the count
        $count++;
        
		// today's background
		if( $date == $args['todayFormatted'] ) {
			echo "\t" . '<div class="todayBackground day' . $count . '"></div>' . "\n";
		}
		
		// open div
		echo "\t" . '<div class="dayBlock day' . $count . '">' . "\n";
		
		// date
		printHTMLElement("div", "date", $dateArray["shortdate"], 2, false, $dateArray["longdate"]);
		
		// opponent
		if( "" != $dateArray["opponent"] ) {
			printHTMLElement("div", "opponent", $dateArray["opponent"]);
		}
		
		// get the game
		$gameArray = $dateArray['games'][0];
		
		// Double Header
		// ================================================================================
		if( 2 == count($dateArray['games']) ) {
			
			// loop through each game
			foreach( $dateArray['games'] as $gameArray ) {
				
				// get the game number
				$gameNumber = ( $gameArray == $dateArray['games'][0] ) ? "first" : "second";
				
				// link
				if( "" != $gameArray['link'] ) {
					echo "\t\t" . '<a href="javascript:openURL(\'' . $gameArray['link'] . '\');">' . "\n";
				}
				
				// in-progress
				if( 'mid-event' == $gameArray['status'] ) { 
					
					// inning
					printHTMLElement("div", "doubleheader $gameNumber inning", $gameArray["inning"] . $gameArray["inningHalfImage"], 3, true);
					
					// score
					printHTMLElement("div", "doubleheader $gameNumber score", $gameArray["score"], 3, true);
				}
				
				// future
				else if( 'pre-event' == $gameArray['status'] ) {
					
					// time
					printHTMLElement("div", "doubleheader $gameNumber time", $gameArray["startTime"], 3, true);
					
					// media
					if( "TV" == $args['media'] ) {
						$media = $gameArray["tv"];
					}
					
					else if( "Radio" == $args['media'] ) {
						$media = $gameArray["radio"];
					}
					
					printHTMLElement("div", "doubleheader $gameNumber media", $media, 3);
				}
				
				// completed
				else if( 'post-event' == $gameArray['status'] ) {
					
					// win/loss
					printHTMLElement("div", "doubleheader $gameNumber winOrLoss", $gameArray["winOrLoss"], 3, true);
					
					// score
					printHTMLElement("div", "doubleheader $gameNumber finalScore", $gameArray["score"], 3, true);
				}
		
                // postponed
                else if( 'postponed' == $gameArray['status'] ) {
                    
                    // postponed
                    printHTMLElement("div", "doubleheader $gameNumber postponed", "Postponed", 3, true);
                }
                
                // delayed
                else if( 'delayed' == $gameArray['status'] ) {
                    
                    // delayed
                    printHTMLElement("div", "doubleheader $gameNumber delayed", "Delayed", 3, true);
                }
                
                // suspended
                else if( 'suspended' == $gameArray['status'] ) {
                    
                    // suspended
                    printHTMLElement("div", "doubleheader $gameNumber suspended", "Suspended", 3, true);
                }
				
				else {
					
					// error
					printHTMLElement("div", "doubleheader $gameNumber error", "Error.");
				}
				
				// link
				if( "" != $gameArray['link'] ) {
					echo "\t\t" . '</a>' . "\n";
				}
			}
			
			// both games
			$bothGames = '';
			$bothGamesTitle = '';
			
			foreach( $dateArray['games'] as $gameArray ) {
				
				// add in a slash
				if( '' != $bothGames ) {
					$bothGames .= ' / ';
				}
				
				if( '' != $bothGamesTitle ) {
					$bothGamesTitle .= ' / ';
				}
				
				// in-progress
				if( 'mid-event' == $gameArray['status'] ) { 
					
					// score
					$bothGames .= $gameArray["inningHalfInningImageAndScore"];
					$bothGamesTitle .= $gameArray["inningHalfInningAndScore"];
				}
				
				// future
				else if( 'pre-event' == $gameArray['status'] ) {
					
					// time
					$bothGames .= $gameArray["startTime"];
					$bothGamesTitle .= $gameArray["startTime"];
				}
				
				// completed
				else if( 'post-event' == $gameArray['status'] ) {
					
					// win/loss and score
					$bothGames .= $gameArray["winOrLossAndScore"];
					$bothGamesTitle .= $gameArray["winOrLossAndScore"];
				}
		
                // postponed
                else if( 'postponed' == $gameArray['status'] ) {
                    
                    // postponed
					$bothGames .= "Postponed";
					$bothGamesTitle .= "Postponed";
                }
                
                // delayed
                else if( 'delayed' == $gameArray['status'] ) {
                    
                    // delayed
					$bothGames .= "Delayed";
					$bothGamesTitle .= "Delayed";
                }
                
                // suspended
                else if( 'suspended' == $gameArray['status'] ) {
                    
                    // suspended
					$bothGames .= "Postponed";
					$bothGamesTitle .= "Postponed";
                }
			}
			
			printHTMLElement("div", "doubleheader bothgames", $bothGames, 2, false, $bothGamesTitle);
		}
		
		// No Game
		// ================================================================================
		else if( ! isset($gameArray['status']) ) {
			
			printHTMLElement("div", "none", "None", 2, true);
		}
		
		// Postponed 
		// ================================================================================
		else if( 'postponed' == $gameArray['status'] ) {
			
			// postponed
			printHTMLElement("div", "postponed", "Postponed");
		}
		
		// Delayed 
		// ================================================================================
		else if( 'delayed' == $gameArray['status'] ) {
			
			// delayed
			printHTMLElement("div", "delayed", "Delayed");
		}
		
		// Suspended 
		// ================================================================================
		else if( 'suspended' == $gameArray['status'] ) {
			
			// suspended
			printHTMLElement("div", "suspended", "Suspended");
		}
		
		// In Progress Game
		// ================================================================================
		else if( 'mid-event' == $gameArray['status'] ) {
			
			// link
			if( "" != $gameArray['link'] ) {
				echo "\t\t" . '<a href="javascript:openURL(\'' . $gameArray['link'] . '\');">' . "\n";
			}
			
			// inning
			printHTMLElement("div", "inning", $gameArray["inning"] . $gameArray["inningHalfImage"], 3, true);
			
			// score
			printHTMLElement("div", "score", $gameArray["score"], 3, true);
			
			// inning and score
			printHTMLElement("div", "inningAndScore", $gameArray["inningHalfInningImageAndScore"], 3, false, $gameArray["inningHalfInningAndScore"]);
			
			// link
			if( "" != $gameArray['link'] ) {
				echo "\t\t" . '</a>' . "\n";
			}
			
			// outs
			printHTMLElement("div", "outs", $gameArray["outs"], 2, true);
				
			// men on base
			printHTMLElement("div", "menOnBase", $gameArray["menOnBase"]);
		}
		
		// Future Game
		// ================================================================================
		else if( 'pre-event' == $gameArray['status'] ) {
			
			// link
			if( "" != $gameArray['link'] ) {
				echo "\t\t" . '<a href="javascript:openURL(\'' . $gameArray['link'] . '\');">' . "\n";
			}
			
			// time
			printHTMLElement("div", "time", $gameArray["startTime"], 3, true);
			
			// media
			if( "TV" == $args['media'] ) {
				$media = $gameArray["tv"];
			}
			
			else if( "Radio" == $args['media'] ) {
				$media = $gameArray["radio"];
			}
			
			printHTMLElement("div", "media", $media, 3);
			
			// link
			if( "" != $gameArray['link'] ) {
				echo "\t\t" . '</a>' . "\n";
			}
			
			// team starting pitcher
			printHTMLElement("div", "pitcher", $gameArray["teamStarter"]);
			
			// opponent starting pitcher
			printHTMLElement("div", "pitcher", $gameArray["opponentStarter"]);
		}
		
		// Completed Game
		// ================================================================================
		else if( 'post-event' == $gameArray['status'] ) {
			
			// link
			if( "" != $gameArray['link'] ) {
				echo "\t\t" . '<a href="javascript:openURL(\'' . $gameArray['link'] . '\');">' . "\n";
			}
			
			// win/loss
			printHTMLElement("div", "winOrLoss", $gameArray["winOrLoss"], 3, true);
			
			// score
			printHTMLElement("div", "score", $gameArray["score"], 3, true);
			
			// win/loss and score
			printHTMLElement("div", "winOrLossAndScore", $gameArray["winOrLossAndScore"], 3);
			
			// link
			if( "" != $gameArray['link'] ) {
				echo "\t\t" . '</a>' . "\n";
			}
			
			// winning pitcher
			printHTMLElement("div", "pitcher", $gameArray["winningPitcher"]);
			
			// losing pitcher
			printHTMLElement("div", "pitcher", $gameArray["losingPitcher"]);
		}
		
		// Error
		// ================================================================================
		else {
		
			echo "\t\t" . '<span title="Error: status \'' . $game['status'] . '\'">Error.</span>' . "\n";
		}
		
		// ================================================================================
		
		// close div
		echo "\t" . '</div>' . "\n";
	}
	
	// close the div
	echo '</div>' . "\n";
	echo '<!-- end of data -->' . "\n";
	
	// ================================================================================
	// Print Utility Functions
	// ================================================================================
	function printHTMLElement($elementType, $elementClass, $contents, $tabIndent=2, $hideTitle=false, $differentTitle=null) {
		
		// print tabs
		for( $i=0; $i<$tabIndent; $i++ ) {
			echo "\t";
		}
		
		// get the title
		if( !$hideTitle ) {
						
			if( isset($differentTitle) ) {
				$titleContents = $differentTitle;
			}
			
			else {
				$titleContents = $contents;
			}
			
			// create the entire attribute
			$title = ' title="' . $titleContents . '"';
		}
		
		// hide the title
		else {
			$title = '';
		}
		
		// print element
		echo '<' . $elementType . ' class="'  .$elementClass . '"' . $title . '>';
			
			if( "" == $contents ) {
				echo '&nbsp;';
			}
			
			else {
				echo $contents;
			}
			
		echo '</' . $elementType . '>';
		
		// print line return
		echo "\n";
	}
	
	// ================================================================================
	// XML Node Utility Functions
	// ================================================================================
	function getAttributeOfFirstChildElementByTagName($node, $fullName, $attribute) {
	
		$node = getFirstChildElementByTagName($node, $fullName);
		
		if( $node ) {
			return $node->getAttribute($attribute);
		}
		
		else {
			return "";
		}
	}
	
	function getFirstChildElementByTagName($node, $fullName) {
		
		// nested elements
		if( substr_count($fullName, '/') ) {
			$name = substr($fullName, 0, stripos($fullName, '/'));
			$restOfName = substr($fullName, stripos($fullName, '/')+1);
		}
		
		// flat element
		else {
			$name = $fullName;
			$restOfName = '';
		}
		
		// loop through children
		$children = $node->childNodes;
		foreach( $children as $child ) {
			if( $child->tagName == $name ) {
				
				// nested elements
				if( $restOfName != '' ) {
					return getFirstChildElementByTagName($child, $restOfName, '');
				}
				
				// flat element
				else {
					return $child;
				}
			}
		}
	}
?>